@@ -12,7 +12,7 @@
 #
 ##############################################################################
 """
-$Id: memcached.py 89069 2008-07-30 22:22:56Z srichter $
+$Id: memcached.py 89092 2008-07-31 14:34:22Z srichter $
 """
 __docformat__ = 'restructuredtext'
 import md5
@@ -123,13 +123,13 @@ class MemCachedSessionDataContainer(persistent.Persistent, Contained):
 
 
 class MemCacheData(dict):
-    """See zope.app.session.interfaces.ISessionData
+    """See zope.session.interfaces.ISessionData
     """
     interface.implements(ISessionPkgData)
 
 
 class MemCacheSessionData(dict):
-    """See zope.app.session.interfaces.ISessionData"""
+    """See zope.session.interfaces.ISessionData"""
     interface.implements(ISessionData)
     lastAccessTime = 0
 
